timeseries.curve_geometry — GDA Toolbox v1.0 Manual

# timeseries.curve_geometry

This Cython module contains the core algorithms for the geometry of curves.

If a function requires its own explicit iterator in a loop, probably it should go here. Anything that is just a vectorized operation in NumPy or Pandas can go in plain python elsewhere.

See http://docs.cython.org/src/tutorial/np.html for ideas on writing efficient code in Cython.

This module is compiled by either of these commands
  - `python setup.py install` (as called by `pip` for standard installation and use)
  - `python setup.py build_ext --inplace` (as run by developers for code testing)

## Notes

Automatically-generated online documentation will never see the C-only functions that are defined with `cdef` in Cython, as shown in http://cython.readthedocs.io/en/latest/src/reference/extension_types.html Because of the limitations of Sphinx, you’ll have to simply view the sourcecode for further information. For this module, these C-only functions include

> - `homology.dim0.root()`
> - `homology.dim0.connected()`
> - `homology.dim0.merge()`

## Copyright

- This file is part of https://github.com/geomdata/gda-public/
- 2015, 2016, 2017 by Geometric Data Analytics, Inc. (http://geomdata.com)
- AGPL license. See LICENSE or https://github.com/geomdata/gda-public/blob/master/LICENSE

Functions

`cdist`(XA, XB[, metric, p, V, VI, w]) | Computes distance between each pair of the two collections of inputs.
`cleanup`(ndarray time, ndarray position, …) | Throw out bad points by speed comparison.
`contour_crossings`(x[, contour]) | Take a one dimensional array and find the positions where the array crosses (or touches) a contour.
`euclidean`(u, v) | Computes the Euclidean distance between two 1-D arrays.
`frenet_frame`(velocity, acceleration) | Find the Frenet frame using QR-decomposition at each time step.
`frenet_kappa_tau`(ndarray velocity, …) | Compute KAPPA curvature and TAU torsion for a curve
`mollifier`(time, position[, refinement, width]) | Smooth function in a way that retains shape by adding new graph values via the linear interpolate and smoothing via convolution with the Friedrichs’ mollifier.
`mollifier_uneven`(time, position[, …]) | Smooth function in a way that retains shape by adding new graph values via the linear interpolate and smoothing via convolution with the Friedrichs’ mollifier.
`secant_arclength`(ndarray position) | Compute the cumulative arc-length sample-by-sample.
`secant_derivative`(ndarray time, …) | Compute the secant derivatives using points equally spaced BY INDEX.
`secant_jump`(ndarray position) | Compute the secant displacement sample-by-sample.
`similarity_matrix`(a, b[, func]) | similarity_matrix computes the similarity matrix of two iterables given a specified metric, defaulting to a euclidean metric.
`tangent_arclength`(ndarray time, ndarray velocity) | Compute the cumulative arc-length by integrating speed.

### Table of Contents

- timeseries.curve_geometry
  - Notes
  - Copyright

#### Previous topic

timeseries.fast_algorithms

#### Next topic

homology.dim0